@@ -7,6 +7,11 @@ Puppet::Type.newtype(:designate_rootwrap_config) do
     newvalues(/\S+\/\S+/)
   end
 
+  newparam(:ensure_absent_val) do
+    desc 'A value that is specified as the value property will behave as if ensure => absent was specified'
+    defaultto('<SERVICE DEFAULT>')
+  end
+
   newproperty(:value) do
     desc 'The value of the setting to be defined.'
     munge do |value|
