@@ -56,7 +56,8 @@ describe 'designate::api' do
         is_expected.to contain_designate_config('service:api/quotas_verify_project_id').with_value('<SERVICE DEFAULT>')
         is_expected.to_not contain_designate__keystone__authtoken('designate_config')
         is_expected.to contain_oslo__middleware('designate_config').with(
-          :enable_proxy_headers_parsing => '<SERVICE DEFAULT>'
+          :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+          :max_request_body_size        => '<SERVICE DEFAULT>',
         )
       end
     end
@@ -82,6 +83,7 @@ describe 'designate::api' do
           :enabled_extensions_admin      => 'reports,quotas,zones',
           :quotas_verify_project_id      => false,
           :enable_proxy_headers_parsing  => true,
+          :max_request_body_size         => 102400,
         })
       end
 
@@ -104,7 +106,8 @@ describe 'designate::api' do
         is_expected.to contain_designate_config('service:api/enabled_extensions_admin').with_value(params[:enabled_extensions_admin])
         is_expected.to contain_designate_config('service:api/quotas_verify_project_id').with_value(false)
         is_expected.to contain_oslo__middleware('designate_config').with(
-          :enable_proxy_headers_parsing => params[:enable_proxy_headers_parsing]
+          :enable_proxy_headers_parsing => params[:enable_proxy_headers_parsing],
+          :max_request_body_size        => params[:max_request_body_size],
         )
       end
     end
